/* Copyright (C) 2011, 2012, 2013 by Bundesanstalt für Gewässerkunde
 * Software engineering by Intevation GmbH
 *
 * This file is Free Software under the GNU AGPL (>=v3)
 * and comes with ABSOLUTELY NO WARRANTY! Check out the
 * documentation coming with Dive4Elements River for details.
 */

package org.dive4elements.river.artifacts.uinfo.salix;

import org.apache.log4j.Logger;
import org.dive4elements.artifactdatabase.state.Facet;
import org.dive4elements.artifacts.Artifact;
import org.dive4elements.artifacts.CallContext;
import org.dive4elements.river.artifacts.D4EArtifact;
import org.dive4elements.river.artifacts.common.AbstractCalculationResult;
import org.dive4elements.river.artifacts.common.AbstractCalculationResults;
import org.dive4elements.river.artifacts.model.CalculationResult;
import org.dive4elements.river.artifacts.model.DataFacet;

/**
 * Facet of the U-Info salix line curve.
 */
public class SalixLineResultFacet extends DataFacet {

    private static final long serialVersionUID = 1L;

    private static Logger log = Logger.getLogger(SalixLineResultFacet.class);

    private int resultIndex;

    public SalixLineResultFacet() {
        // required for clone operation deepCopy()
    }

    public SalixLineResultFacet(final String name, final String description) {
        super(name, description);
    }

    @Override
    public final Object getData(final Artifact artifact, final CallContext context) {

        log.debug("Get data for result at index: " + this.resultIndex);

        final D4EArtifact flys = (D4EArtifact) artifact;

        final CalculationResult res = (CalculationResult) flys.compute(context, this.hash, this.stateId, this.type, false);

        final AbstractCalculationResults<AbstractCalculationResult> data = (AbstractCalculationResults<AbstractCalculationResult>) res.getData();

        return data.getResults().get(this.resultIndex);
    }

    /** Copy deeply. */
    @Override
    public Facet deepCopy() {
        // FIXME: why not simply use the full constructor instead?
        final SalixLineResultFacet copy = new SalixLineResultFacet();
        // FIXME: why does DataFacet does not override set? Bad access to variables of parent!
        copy.set(this);
        copy.type = this.type;
        copy.hash = this.hash;
        copy.stateId = this.stateId;
        return copy;
    }
}